pub struct DetectionConfig {
pub n_plus_one_threshold: u32,
pub window_duration_ms: u64,
pub slow_query_threshold_ms: u64,
pub slow_query_min_occurrences: u32,
pub max_fanout: u32,
pub chatty_service_min_calls: u32,
pub pool_saturation_concurrent_threshold: u32,
pub serialized_min_sequential: u32,
pub sanitizer_aware_classification: SanitizerAwareMode,
}Expand description
Per-detector knobs. Maps 1:1 to [detection] in TOML.
Fields
n_plus_one_threshold: u32N+1 detection threshold: minimum repeated similar queries to flag.
window_duration_ms: u64Sliding window duration in milliseconds for N+1 detection.
slow_query_threshold_ms: u64Threshold in milliseconds above which an operation is considered slow.
slow_query_min_occurrences: u32Minimum occurrences of a slow template to flag as a finding.
max_fanout: u32Maximum child spans per parent before flagging excessive fanout.
chatty_service_min_calls: u32Minimum HTTP outbound calls per trace to flag as chatty service.
pool_saturation_concurrent_threshold: u32Peak concurrent SQL spans per service to flag pool saturation.
serialized_min_sequential: u32Minimum sequential independent sibling calls to flag as serialized.
sanitizer_aware_classification: SanitizerAwareModeSanitizer-aware classification mode for SQL N+1 vs redundant.
See crate::detect::sanitizer_aware::SanitizerAwareMode.