pub enum RelationStrategy {
Current,
Associated,
}Expand description
RelationStrategy indicates the flow control strategy based on the relation of invocations.
Variants
Current
Current means flow control by current resource directly.
Associated
Associated means flow control by the associated resource rather than current resource.