pub struct Rule {Show 15 fields
pub id: Id,
pub resource: String,
pub ref_resource: String,
pub calculate_strategy: CalculateStrategy,
pub control_strategy: ControlStrategy,
pub relation_strategy: RelationStrategy,
pub threshold: f64,
pub warm_up_period_sec: u32,
pub warm_up_cold_factor: u32,
pub max_queueing_time_ms: u32,
pub stat_interval_ms: u32,
pub low_mem_usage_threshold: u64,
pub high_mem_usage_threshold: u64,
pub mem_low_water_mark: u64,
pub mem_high_water_mark: u64,
}Expand description
Rule describes the strategy of flow control, the flow control strategy is based on QPS statistic metric
Fields
id: Idid represents the unique ID of the rule (optional).
resource: Stringresource represents the resource name.
ref_resource: Stringcalculate_strategy: CalculateStrategycontrol_strategy: ControlStrategyrelation_strategy: RelationStrategythreshold: f64threshold means the threshold during stat_interval_ms
If stat_interval_ms is 1000(1 second), threshold means QPS
warm_up_period_sec: u32warm_up_cold_factor: u32max_queueing_time_ms: u32max_queueing_time_ms only takes effect when control_strategy is Throttling.
When max_queueing_time_ms is 0, it means Throttling only controls interval of requests,
and requests exceeding the threshold will be rejected directly.
stat_interval_ms: u32stat_interval_ms indicates the statistic interval and it’s the optional setting for flow Rule. If user doesn’t set stat_interval_ms, that means using default metric statistic of resource. If the stat_interval_ms user specifies can not reuse the global statistic of resource, sentinel will generate independent statistic structure for this self.
low_mem_usage_threshold: u64adaptive flow control algorithm related parameters limitation: low_mem_usage_threshold > high_mem_usage_threshold && mem_high_water_mark > mem_low_water_mark
- if the current memory usage is less than or equals to mem_low_water_mark, threshold == low_mem_usage_threshold
- if the current memory usage is more than or equals to mem_high_water_mark, threshold == high_mem_usage_threshold
- if the current memory usage is in (mem_low_water_mark, mem_high_water_mark), threshold is in (high_mem_usage_threshold, low_mem_usage_threshold)
high_mem_usage_threshold: u64mem_low_water_mark: u64mem_high_water_mark: u64Implementations
Sourceimpl Rule
impl Rule
pub fn is_stat_reusable(&self, other: &Self) -> bool
pub fn need_statistic(&self) -> bool