pub struct Rule {
pub id: String,
pub resource: String,
pub metric_type: MetricType,
pub threshold: u32,
}Expand description
Rule describes the policy for system resiliency.
Fields
id: Stringid represents the unique ID of the rule (optional).
resource: Stringresource represents the target resource definition
metric_type: MetricTypemetric_type indicates the type of the trigger metric.
threshold: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Rule
impl<'de> Deserialize<'de> for Rule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Rule
impl JsonSchema for Rule
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl SentinelRule for Rule
impl SentinelRule for Rule
impl Eq for Rule