DefaultPropertyHandler

Struct DefaultPropertyHandler 

pub struct DefaultPropertyHandler<P: SentinelRule + PartialEq + DeserializeOwned> { /* private fields */ }
Available on crate features ds_etcdv3 or ds_consul or ds_k8s only.
DefaultPropertyHandler encapsulate the Converter and updater of property. One DefaultPropertyHandler instance is to handle one property type. DefaultPropertyHandler should check whether current property is consistent with last update property converter convert the message to the specific property updater update the specific property to downstream.

Implementations