Module normalize

Module normalize 

Normalization stage: canonicalizes SQL queries and HTTP URLs.

Modules

http
HTTP URL normalizer.
sql
Homemade SQL tokenizer/normalizer.

Structs

NormalizedEvent
A span event enriched with its normalized template and extracted parameters.

Functions

normalize
Normalize a single event by dispatching on its type.
normalize_all
Normalize a batch of events.