pub fn normalize(event: SpanEvent) -> NormalizedEventExpand description
Normalize a single event by dispatching on its type.
Also sanitizes trace_id and span_id to enforce maximum length.
pub fn normalize(event: SpanEvent) -> NormalizedEventNormalize a single event by dispatching on its type.
Also sanitizes trace_id and span_id to enforce maximum length.